LWN.net Logo

O20.3int

From:  Con Kolivas <kernel@kolivas.org>
To:  linux kernel mailing list <linux-kernel@vger.kernel.org>
Subject:  [PATCH]O20.3int
Date:  Tue, 16 Sep 2003 11:00:44 +1000
Cc:  Andrew Morton <akpm@osdl.org>

Yep I really hate doing this, sorry. This is what I was supposed to do in 
O20.2int.

applies to O20.2int

Con
--- linux-2.6.0-test5-mm2-O20.2/kernel/sched.c	2003-09-16 09:27:57.000000000 +1000
+++ linux-2.6.0-test5-mm2-O20.3/kernel/sched.c	2003-09-16 10:50:49.000000000 +1000
@@ -1426,11 +1426,11 @@ void scheduler_tick(int user_ticks, int 
 		 * equal priority.
 		 *
 		 * This only applies to tasks in the interactive
 		 * delta range with at least MIN_TIMESLICE to requeue.
 		 */
 		if (TASK_INTERACTIVE(p) && !((task_timeslice(p) -
 			p->time_slice) % TIMESLICE_GRANULARITY(p)) &&
-			(p->time_slice >= MIN_TIMESLICE) &&
+			(p->time_slice >= TIMESLICE_GRANULARITY(p)) &&
 			(p->array == rq->active)) {
 
 			dequeue_task(p, rq->active);
@@ -1426,11 +1426,11 @@ void scheduler_tick(int user_ticks, int 
 		 *
 		 * This only applies to tasks in the interactive
-		 * delta range with at least MIN_TIMESLICE to requeue.
+		 * delta range with at least TIMESLICE_GRANULARITY to requeue.
 		 */
 		if (TASK_INTERACTIVE(p) && !((task_timeslice(p) -

Copyright © 2003, Eklektix, Inc.
Comments and public postings are copyrighted by their creators.
Linux is a registered trademark of Linus Torvalds